package com.hungraim.ism.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ism.pojo.vo.disable.DisableVO;
import com.hungraim.ism.service.DisableService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 失能申请Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/disable")
@Slf4j
public class DisableController {

    @Autowired
    private DisableService disableService;

    /**
     * 失能人员信息列表
     *
     * @param organId            适用机构代码
     * @param districtProvincial 所在省
     * @param districtCity       所在市
     * @param districtArea       所在区域
     * @param realName           参保人员姓名
     * @param certiCode          参保人身份证号码
     * @param treatmentType      待遇类型
     * @param applyStatus        审核状态
     * @param pageNum            当前页
     * @param pageSize           每页几条数据
     * @return 失能人员信息列表
     */
    @RequestMapping("/disableList")
    public Result<List<DisableVO>> disableList(String organId, String districtProvincial,
                                               String districtCity, String districtArea,
                                               String realName, String certiCode, String treatmentType,
                                               String applyStatus, int pageNum, int pageSize) {
        IPage<DisableVO> iPage = disableService.disableList(organId, districtProvincial,
                districtCity, districtArea, realName, certiCode, treatmentType, applyStatus, pageNum, pageSize);
        return Result.success(iPage.getRecords());
    }

}
